@@ -37,19 +37,19 @@ def slog(s, target: str = "target",logger = None):
 
 def get_last_sync_time(target_session) -> datetime:
     """从目标数据库获取上次同步时间"""
-    metadata_entry = target_session.query(SyncMetadata).filter_by(table_name="sync_metadata").first()
+    metadata_entry = target_session.query(SyncMetadata).filter_by(table_name="ai_sync_metadata").first()
     if metadata_entry:
         return metadata_entry.last_sync_time
     return datetime(1970, 1, 1) # 默认一个很早的时间
 
 def update_last_sync_time(target_session, new_sync_time: datetime):
     """更新目标数据库的上次同步时间"""
-    metadata_entry = target_session.query(SyncMetadata).filter_by(table_name="sync_metadata").first()
+    metadata_entry = target_session.query(SyncMetadata).filter_by(table_name="ai_sync_metadata").first()
     if metadata_entry:
         metadata_entry.last_sync_time = new_sync_time
     else:
         # 如果不存在，则创建
-        new_metadata = SyncMetadata(table_name="sync_metadata", last_sync_time=new_sync_time)
+        new_metadata = SyncMetadata(table_name="ai_sync_metadata", last_sync_time=new_sync_time)
         target_session.add(new_metadata)
     target_session.commit()
     print(f"Updated last sync time to: {new_sync_time}")
