@@ -73,6 +73,7 @@ class Intel():
                 ):
         database_url = database_url or os.getenv("database_url")
         assert database_url
+        assert "aiomysql" not in database_url
         self.engine = create_engine(database_url, echo=False, # echo=True 仍然会打印所有执行的 SQL 语句
                                     pool_size=10,        # 连接池中保持的连接数
                                     max_overflow=20,     # 当pool_size不够时，允许临时创建的额外连接数
@@ -85,11 +86,10 @@ class Intel():
         
         if model_name in ["gemini-2.5-flash-preview-05-20-nothinking",]:
             self.llm = BianXieAdapter(model_name = model_name)
-        elif model_name in ["doubao-1-5-pro-256k-250115",]:
+        elif model_name in ["doubao-1-5-pro-256k-250115","doubao-1-5-pro-32k-250115"]:
             self.llm = ArkAdapter(model_name = model_name)
         else:
-            print('Use BianXieAdapter')
-            self.llm = BianXieAdapter()
+            raise Exception("error llm name")
         self.logger = logger or pro_craft_logger
         
     def _get_latest_prompt_version(self,target_prompt_id,session):
